﻿# Define paths and names
$localScriptDir = "C:\Scripts"
$scriptName = "LansweeperServiceManager.ps1"
$localScriptPath = Join-Path -Path $localScriptDir -ChildPath $scriptName
$logFilePath = Join-Path -Path $localScriptDir -ChildPath "LansweeperServiceManager_log.txt"
$errorLogPath = Join-Path -Path $localScriptDir -ChildPath "LansweeperServiceManager_errorlog.txt"

# Ensure the local script directory exists
if (-not (Test-Path $localScriptDir)) {
    New-Item -ItemType Directory -Path $localScriptDir
}

# Logging function to create weekly log files
function Write-Log {
    Param ([string]$message)
    $currentDate = Get-Date
    $year = $currentDate.ToString("yyyy")
    $week = Get-Date $currentDate -UFormat "%V"
    $logFileName = "LansweeperServiceManager_log_$year-Week$week.txt"
    $logFilePath = Join-Path -Path $localScriptDir -ChildPath $logFileName
    $timestamp = $currentDate.ToString('yyyy-MM-dd HH:mm:ss')
    "$($timestamp): $message" | Out-File -FilePath $logFilePath -Append
}

# Error logging function to write errors to a single file
function Log-Error {
    Param ([string]$errorMessage)
    $currentDate = Get-Date
    $timestamp = $currentDate.ToString('yyyy-MM-dd HH:mm:ss')
    "$($timestamp): $errorMessage" | Out-File -FilePath $errorLogPath -Append
}

# Service management tasks
Write-Log "Checking for Lansweeper Agent service..."
$service = Get-Service -Name LansweeperAgentService -ErrorAction SilentlyContinue

if ($service) {
    Write-Log "Lansweeper Agent service found. Proceeding with management tasks..."
    Try {
        # Stop the Lansweeper Agent service
        Write-Log "Stopping Lansweeper Agent service..."
        Stop-Service -Name LansweeperAgentService -ErrorAction Stop

        # Modify the configuration file
        # Remove timestamps from LsAgent.ini
        $filePath = "C:\Program Files (x86)\LansweeperAgent\LsAgent.ini"
        (Get-Content $filePath) | Where-Object { -not ($_ -match "^Last") } | Set-Content $filePath

        # Start the Lansweeper Agent service
        Write-Log "Starting Lansweeper Agent service..."
        Start-Service -Name LansweeperAgentService -ErrorAction Stop
        Write-Log "Lansweeper Agent service management completed successfully."
    } Catch {
        Log-Error "Error occurred: $($_.Exception.Message)"
    }
} else {
    Log-Error "Lansweeper Agent service not found. No action taken."
}


